Related Projects
================

This page lists related open-source projects.

**Graphical Schematic Capture:**

- `Xschem <https://xschem.sourceforge.io/stefan/index.html>`_: Schematic capture and netlisting EDA tool
  
  - currently the most popular in open-source analog IC design

- `XCircuit <http://www.opencircuitdesign.com/xcircuit/>`_: Schematic capture program written by Tim Edwards
- `Lepton EDA <https://github.com/lepton-eda/lepton-eda>`_: GPL Electronic Design Automation
  
  - fork of gEDA project
  - focus on PCB design (?)

- `KiCad <https://www.kicad.org/>`_: Schematic Capture & PCB Design Software

  - focus on PCB design

- `Qucs <https://qucs.sourceforge.net/index.html>`_: Quite universal circuit simulator
- `Qucs-S <https://ra3xdh.github.io/>`_: Qucs with SPICE
- `Xic <http://www.wrcad.com/xictools/index.html>`_
- `Revolution EDA <https://reveda.eu/>`_: symbol, schematic & layout editing, new project (2023)
  
**Textual Schematic Capture:**

- `HDL21 <https://github.com/dan-fritchman/Hdl21>`_: Analog Hardware Description Library in Python 
- `SKiDL <https://devbisme.github.io/skidl/>`_: Describe electronic circuits using Python (mainly for PCB design?)
- `PySpice <https://pyspice.fabrice-salvaire.fr/>`_: Python interface to Ngspice and Xyce

**Analog Simulation:**

- `Ngspice <https://ngspice.sourceforge.io/>`_: Spice circuit simulator
  
  - most popular in open-source IC design

- `Xyce <https://xyce.sandia.gov/>`_: SPICE-compatible, high-performance analog circuit simulator
  
  - faster than Ngspice, but harder to install.

- `Gnucap <http://www.gnucap.org/>`_ GNU Circuit Analysis Package
- `Qucsator <https://github.com/Qucs/qucsator>`_: Circuit simulator of the Qucs project
- `OpenVAF <https://openvaf.semimod.de/>`_: Next-Generation Verilog-A compiler
  
  - e.g. for use with Ngspice
  - see also its fork `OpenVAF-Reloaded <https://github.com/OpenVAF/OpenVAF-Reloaded>`_

**IC Layout Entry:**

- `KLayout <https://www.klayout.de/>`_: Layout Viewer and Editor

  - currently the most popular in open-source analog IC design

- `Magic <http://opencircuitdesign.com/magic/>`_: Famous layout tool by John Ousterhout, first release 1983.
- `Xic <http://www.wrcad.com/xictools/index.html>`_
- `Revolution EDA <https://reveda.eu/>`_: symbol, schematic & layout editing, new project (2023)

**Textual Layout Generation:**

- `GDSFactory <https://gdsfactory.com/>`_
- `openPCells <https://github.com/patrickschulz/openPCells>`_

**Parasitic Extraction:**

- `FastCap2 <https://github.com/ediloren/FastCap2>`_
- `FasterCap <https://github.com/ediloren/FasterCap>`_
- `Caplet <https://github.com/yuchsiao/caplet>`_

**Optimization:**

- `PyOPUS <https://fides.fe.uni-lj.si/pyopus/>`_: Simulation, Optimization, and Design for circuits and everything else
